#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_BITWISE_ORNOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_BITWISE_ORNOT_HPP_INCLUDED

#include <nt2/bitwise/include/functions/scalar/bitwise_ornot.hpp>

#endif
